Package com.anthropic.core.http
Class HttpRequest
-
- All Implemented Interfaces:
public final class HttpRequest
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classHttpRequest.Builder
-
Field Summary
Fields Modifier and Type Field Description private final HttpMethodmethodprivate final StringbaseUrlprivate final List<String>pathSegmentsprivate final Headersheadersprivate final QueryParamsqueryParamsprivate final HttpRequestBodybody
-
Method Summary
Modifier and Type Method Description final HttpMethodmethod()final StringbaseUrl()final List<String>pathSegments()final Headersheaders()final QueryParamsqueryParams()final HttpRequestBodybody()final Stringurl()final HttpRequestbuffered()Returns a request equivalent to this request, but whose body, if any, is buffered (HttpRequestBody.buffered), so it's repeatable. final HttpRequest.BuildertoBuilder()StringtoString()final static HttpRequest.Builderbuilder()-
-
Method Detail
-
method
final HttpMethod method()
-
pathSegments
final List<String> pathSegments()
-
queryParams
final QueryParams queryParams()
-
body
final HttpRequestBody body()
-
buffered
final HttpRequest buffered()
Returns a request equivalent to this request, but whose body, if any, is buffered (HttpRequestBody.buffered), so it's repeatable.
Returns this request unchanged if it has no body or its body is already repeatable.
-
toBuilder
final HttpRequest.Builder toBuilder()
-
builder
final static HttpRequest.Builder builder()
-
-
-
-