Package com.anthropic.errors
Enum CredentialSourceState
-
- All Implemented Interfaces:
-
java.io.Serializable,kotlin.Comparable
public enum CredentialSourceState extends Enum<CredentialSourceState>
-
-
Field Summary
Fields Modifier and Type Field Description private final Stringnameprivate final Integerordinalprivate final EnumEntries<CredentialSourceState>entries
-
Enum Constant Summary
Enum Constants Enum Constant Description NOT_SETNOT_FOUNDLOAD_FAILEDPARTIAL
-
Method Summary
Modifier and Type Method Description final Array<CredentialSourceState>values()Returns an array containing the constants of this enum type, in the order they're declared. final CredentialSourceStatevalueOf(String value)Returns the enum constant of this type with the specified name. final EnumEntries<CredentialSourceState>getEntries()-
-
Method Detail
-
values
final Array<CredentialSourceState> values()
Returns an array containing the constants of this enum type, in the order they're declared.
This method may be used to iterate over the constants.
-
valueOf
final CredentialSourceState valueOf(String value)
Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)
-
getEntries
final EnumEntries<CredentialSourceState> getEntries()
-
-
-
-