Package com.anthropic.models
Class AuthenticationError
-
- All Implemented Interfaces:
public final class AuthenticationError
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAuthenticationError.BuilderA builder for AuthenticationError.
-
Method Summary
Modifier and Type Method Description final Stringmessage()final JsonValue_type()Expected to always return the following:
However, this method can be useful for debugging and logging (e.g.JsonValue.from("authentication_error")final JsonField<String>_message()Returns the raw JSON value of message. final Map<String, JsonValue>_additionalProperties()final AuthenticationError.BuildertoBuilder()final AuthenticationErrorvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static AuthenticationError.Builderbuilder()Returns a mutable builder for constructing an instance of AuthenticationError. -
-
Method Detail
-
_type
final JsonValue _type()
Expected to always return the following:
JsonValue.from("authentication_error")However, this method can be useful for debugging and logging (e.g. if the server responded with an unexpected value).
-
_message
final JsonField<String> _message()
Returns the raw JSON value of message.
Unlike message, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final AuthenticationError.Builder toBuilder()
-
validate
final AuthenticationError validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static AuthenticationError.Builder builder()
Returns a mutable builder for constructing an instance of AuthenticationError.
The following fields are required:
.message()
-
-
-
-