Package com.anthropic.models
Class NotFoundError
-
- All Implemented Interfaces:
public final class NotFoundError
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classNotFoundError.BuilderA builder for NotFoundError.
-
Method Summary
Modifier and Type Method Description final Stringmessage()final JsonValue_type()Expected to always return the following:
However, this method can be useful for debugging and logging (e.g.JsonValue.from("not_found_error")final JsonField<String>_message()Returns the raw JSON value of message. final Map<String, JsonValue>_additionalProperties()final NotFoundError.BuildertoBuilder()final NotFoundErrorvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static NotFoundError.Builderbuilder()Returns a mutable builder for constructing an instance of NotFoundError. -
-
Method Detail
-
_type
final JsonValue _type()
Expected to always return the following:
JsonValue.from("not_found_error")However, this method can be useful for debugging and logging (e.g. if the server responded with an unexpected value).
-
_message
final JsonField<String> _message()
Returns the raw JSON value of message.
Unlike message, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final NotFoundError.Builder toBuilder()
-
validate
final NotFoundError validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static NotFoundError.Builder builder()
Returns a mutable builder for constructing an instance of NotFoundError.
The following fields are required:
.message()
-
-
-
-