Class BetaTextEditorCodeExecutionCreateResultBlock
-
- All Implemented Interfaces:
public final class BetaTextEditorCodeExecutionCreateResultBlock
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classBetaTextEditorCodeExecutionCreateResultBlock.BuilderA builder for BetaTextEditorCodeExecutionCreateResultBlock.
-
Method Summary
Modifier and Type Method Description final BooleanisFileUpdate()final BetaTextEditorCodeExecutionCreateResultBlockParamtoParam()final JsonValue_type()Expected to always return the following:
However, this method can be useful for debugging and logging (e.g.JsonValue.from("text_editor_code_execution_create_result")final JsonField<Boolean>_isFileUpdate()Returns the raw JSON value of isFileUpdate. final Map<String, JsonValue>_additionalProperties()final BetaTextEditorCodeExecutionCreateResultBlock.BuildertoBuilder()final BetaTextEditorCodeExecutionCreateResultBlockvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static BetaTextEditorCodeExecutionCreateResultBlock.Builderbuilder()Returns a mutable builder for constructing an instance of BetaTextEditorCodeExecutionCreateResultBlock. -
-
Method Detail
-
isFileUpdate
final Boolean isFileUpdate()
-
toParam
final BetaTextEditorCodeExecutionCreateResultBlockParam toParam()
-
_type
final JsonValue _type()
Expected to always return the following:
JsonValue.from("text_editor_code_execution_create_result")However, this method can be useful for debugging and logging (e.g. if the server responded with an unexpected value).
-
_isFileUpdate
final JsonField<Boolean> _isFileUpdate()
Returns the raw JSON value of isFileUpdate.
Unlike isFileUpdate, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final BetaTextEditorCodeExecutionCreateResultBlock.Builder toBuilder()
-
validate
final BetaTextEditorCodeExecutionCreateResultBlock validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static BetaTextEditorCodeExecutionCreateResultBlock.Builder builder()
Returns a mutable builder for constructing an instance of BetaTextEditorCodeExecutionCreateResultBlock.
The following fields are required:
.isFileUpdate()
-
-
-
-