Class BetaWebhookSessionStatusRunStartedEventData
-
- All Implemented Interfaces:
public final class BetaWebhookSessionStatusRunStartedEventData
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classBetaWebhookSessionStatusRunStartedEventData.BuilderA builder for BetaWebhookSessionStatusRunStartedEventData.
-
Method Summary
Modifier and Type Method Description final Stringid()ID of the session that triggered the event. final StringorganizationId()final StringworkspaceId()final JsonValue_type()Expected to always return the following:
However, this method can be useful for debugging and logging (e.g.JsonValue.from("session.status_run_started")final JsonField<String>_id()Returns the raw JSON value of id. final JsonField<String>_organizationId()Returns the raw JSON value of organizationId. final JsonField<String>_workspaceId()Returns the raw JSON value of workspaceId. final Map<String, JsonValue>_additionalProperties()final BetaWebhookSessionStatusRunStartedEventData.BuildertoBuilder()final BetaWebhookSessionStatusRunStartedEventDatavalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static BetaWebhookSessionStatusRunStartedEventData.Builderbuilder()Returns a mutable builder for constructing an instance of BetaWebhookSessionStatusRunStartedEventData. -
-
Method Detail
-
organizationId
final String organizationId()
-
workspaceId
final String workspaceId()
-
_type
final JsonValue _type()
Expected to always return the following:
JsonValue.from("session.status_run_started")However, this method can be useful for debugging and logging (e.g. if the server responded with an unexpected value).
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_organizationId
final JsonField<String> _organizationId()
Returns the raw JSON value of organizationId.
Unlike organizationId, this method doesn't throw if the JSON field has an unexpected type.
-
_workspaceId
final JsonField<String> _workspaceId()
Returns the raw JSON value of workspaceId.
Unlike workspaceId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final BetaWebhookSessionStatusRunStartedEventData.Builder toBuilder()
-
validate
final BetaWebhookSessionStatusRunStartedEventData validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static BetaWebhookSessionStatusRunStartedEventData.Builder builder()
Returns a mutable builder for constructing an instance of BetaWebhookSessionStatusRunStartedEventData.
The following fields are required:
.id() .organizationId() .workspaceId()
-
-
-
-