Package com.anthropic.models.messages
Class CodeExecutionOutputBlockParam
-
- All Implemented Interfaces:
public final class CodeExecutionOutputBlockParam
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCodeExecutionOutputBlockParam.BuilderA builder for CodeExecutionOutputBlockParam.
-
Method Summary
Modifier and Type Method Description final StringfileId()final JsonValue_type()Expected to always return the following:
However, this method can be useful for debugging and logging (e.g.JsonValue.from("code_execution_output")final JsonField<String>_fileId()Returns the raw JSON value of fileId. final Map<String, JsonValue>_additionalProperties()final CodeExecutionOutputBlockParam.BuildertoBuilder()final CodeExecutionOutputBlockParamvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CodeExecutionOutputBlockParam.Builderbuilder()Returns a mutable builder for constructing an instance of CodeExecutionOutputBlockParam. -
-
Method Detail
-
_type
final JsonValue _type()
Expected to always return the following:
JsonValue.from("code_execution_output")However, this method can be useful for debugging and logging (e.g. if the server responded with an unexpected value).
-
_fileId
final JsonField<String> _fileId()
Returns the raw JSON value of fileId.
Unlike fileId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CodeExecutionOutputBlockParam.Builder toBuilder()
-
validate
final CodeExecutionOutputBlockParam validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static CodeExecutionOutputBlockParam.Builder builder()
Returns a mutable builder for constructing an instance of CodeExecutionOutputBlockParam.
The following fields are required:
.fileId()
-
-
-
-