Package com.anthropic.models.messages
Class TextEditorCodeExecutionCreateResultBlock
-
- All Implemented Interfaces:
public final class TextEditorCodeExecutionCreateResultBlock
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classTextEditorCodeExecutionCreateResultBlock.BuilderA builder for TextEditorCodeExecutionCreateResultBlock.
-
Method Summary
Modifier and Type Method Description final BooleanisFileUpdate()final TextEditorCodeExecutionCreateResultBlockParamtoParam()final JsonValue_type()Expected to always return the following:
However, this method can be useful for debugging and logging (e.g.JsonValue.from("text_editor_code_execution_create_result")final JsonField<Boolean>_isFileUpdate()Returns the raw JSON value of isFileUpdate. final Map<String, JsonValue>_additionalProperties()final TextEditorCodeExecutionCreateResultBlock.BuildertoBuilder()final TextEditorCodeExecutionCreateResultBlockvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static TextEditorCodeExecutionCreateResultBlock.Builderbuilder()Returns a mutable builder for constructing an instance of TextEditorCodeExecutionCreateResultBlock. -
-
Method Detail
-
isFileUpdate
final Boolean isFileUpdate()
-
toParam
final TextEditorCodeExecutionCreateResultBlockParam toParam()
-
_type
final JsonValue _type()
Expected to always return the following:
JsonValue.from("text_editor_code_execution_create_result")However, this method can be useful for debugging and logging (e.g. if the server responded with an unexpected value).
-
_isFileUpdate
final JsonField<Boolean> _isFileUpdate()
Returns the raw JSON value of isFileUpdate.
Unlike isFileUpdate, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final TextEditorCodeExecutionCreateResultBlock.Builder toBuilder()
-
validate
final TextEditorCodeExecutionCreateResultBlock validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static TextEditorCodeExecutionCreateResultBlock.Builder builder()
Returns a mutable builder for constructing an instance of TextEditorCodeExecutionCreateResultBlock.
The following fields are required:
.isFileUpdate()
-
-
-
-