Class TextEditorCodeExecutionStrReplaceResultBlockParam
-
- All Implemented Interfaces:
public final class TextEditorCodeExecutionStrReplaceResultBlockParam
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classTextEditorCodeExecutionStrReplaceResultBlockParam.BuilderA builder for TextEditorCodeExecutionStrReplaceResultBlockParam.
-
Method Summary
Modifier and Type Method Description final Optional<List<String>>lines()final Optional<Long>newLines()final Optional<Long>newStart()final Optional<Long>oldLines()final Optional<Long>oldStart()final JsonValue_type()Expected to always return the following:
However, this method can be useful for debugging and logging (e.g.JsonValue.from("text_editor_code_execution_str_replace_result")final JsonField<List<String>>_lines()Returns the raw JSON value of lines. final JsonField<Long>_newLines()Returns the raw JSON value of newLines. final JsonField<Long>_newStart()Returns the raw JSON value of newStart. final JsonField<Long>_oldLines()Returns the raw JSON value of oldLines. final JsonField<Long>_oldStart()Returns the raw JSON value of oldStart. final Map<String, JsonValue>_additionalProperties()final TextEditorCodeExecutionStrReplaceResultBlockParam.BuildertoBuilder()final TextEditorCodeExecutionStrReplaceResultBlockParamvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static TextEditorCodeExecutionStrReplaceResultBlockParam.Builderbuilder()Returns a mutable builder for constructing an instance of TextEditorCodeExecutionStrReplaceResultBlockParam. -
-
Method Detail
-
_type
final JsonValue _type()
Expected to always return the following:
JsonValue.from("text_editor_code_execution_str_replace_result")However, this method can be useful for debugging and logging (e.g. if the server responded with an unexpected value).
-
_lines
final JsonField<List<String>> _lines()
Returns the raw JSON value of lines.
Unlike lines, this method doesn't throw if the JSON field has an unexpected type.
-
_newLines
final JsonField<Long> _newLines()
Returns the raw JSON value of newLines.
Unlike newLines, this method doesn't throw if the JSON field has an unexpected type.
-
_newStart
final JsonField<Long> _newStart()
Returns the raw JSON value of newStart.
Unlike newStart, this method doesn't throw if the JSON field has an unexpected type.
-
_oldLines
final JsonField<Long> _oldLines()
Returns the raw JSON value of oldLines.
Unlike oldLines, this method doesn't throw if the JSON field has an unexpected type.
-
_oldStart
final JsonField<Long> _oldStart()
Returns the raw JSON value of oldStart.
Unlike oldStart, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final TextEditorCodeExecutionStrReplaceResultBlockParam.Builder toBuilder()
-
validate
final TextEditorCodeExecutionStrReplaceResultBlockParam validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static TextEditorCodeExecutionStrReplaceResultBlockParam.Builder builder()
Returns a mutable builder for constructing an instance of TextEditorCodeExecutionStrReplaceResultBlockParam.
-
-
-
-