Class TextEditorCodeExecutionToolResultError
-
- All Implemented Interfaces:
public final class TextEditorCodeExecutionToolResultError
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classTextEditorCodeExecutionToolResultError.BuilderA builder for TextEditorCodeExecutionToolResultError.
-
Method Summary
Modifier and Type Method Description final TextEditorCodeExecutionToolResultErrorCodeerrorCode()final Optional<String>errorMessage()final TextEditorCodeExecutionToolResultErrorParamtoParam()final JsonValue_type()Expected to always return the following:
However, this method can be useful for debugging and logging (e.g.JsonValue.from("text_editor_code_execution_tool_result_error")final JsonField<TextEditorCodeExecutionToolResultErrorCode>_errorCode()Returns the raw JSON value of errorCode. final JsonField<String>_errorMessage()Returns the raw JSON value of errorMessage. final Map<String, JsonValue>_additionalProperties()final TextEditorCodeExecutionToolResultError.BuildertoBuilder()final TextEditorCodeExecutionToolResultErrorvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static TextEditorCodeExecutionToolResultError.Builderbuilder()Returns a mutable builder for constructing an instance of TextEditorCodeExecutionToolResultError. -
-
Method Detail
-
errorCode
final TextEditorCodeExecutionToolResultErrorCode errorCode()
-
errorMessage
final Optional<String> errorMessage()
-
toParam
final TextEditorCodeExecutionToolResultErrorParam toParam()
-
_type
final JsonValue _type()
Expected to always return the following:
JsonValue.from("text_editor_code_execution_tool_result_error")However, this method can be useful for debugging and logging (e.g. if the server responded with an unexpected value).
-
_errorCode
final JsonField<TextEditorCodeExecutionToolResultErrorCode> _errorCode()
Returns the raw JSON value of errorCode.
Unlike errorCode, this method doesn't throw if the JSON field has an unexpected type.
-
_errorMessage
final JsonField<String> _errorMessage()
Returns the raw JSON value of errorMessage.
Unlike errorMessage, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final TextEditorCodeExecutionToolResultError.Builder toBuilder()
-
validate
final TextEditorCodeExecutionToolResultError validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static TextEditorCodeExecutionToolResultError.Builder builder()
Returns a mutable builder for constructing an instance of TextEditorCodeExecutionToolResultError.
The following fields are required:
.errorCode() .errorMessage()
-
-
-
-