Interface MemoryStoreServiceAsync
-
- All Implemented Interfaces:
public interface MemoryStoreServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceMemoryStoreServiceAsync.WithRawResponseA view of MemoryStoreServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
-
-
Method Detail
-
withRawResponse
abstract MemoryStoreServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract MemoryStoreServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
memories
abstract MemoryServiceAsync memories()
-
memoryVersions
abstract MemoryVersionServiceAsync memoryVersions()
-
create
CompletableFuture<BetaManagedAgentsMemoryStore> create(MemoryStoreCreateParams params)
Create a memory store
-
create
abstract CompletableFuture<BetaManagedAgentsMemoryStore> create(MemoryStoreCreateParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<BetaManagedAgentsMemoryStore> retrieve(String memoryStoreId)
Retrieve a memory store
-
retrieve
CompletableFuture<BetaManagedAgentsMemoryStore> retrieve(String memoryStoreId, MemoryStoreRetrieveParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<BetaManagedAgentsMemoryStore> retrieve(String memoryStoreId, MemoryStoreRetrieveParams params)
-
retrieve
abstract CompletableFuture<BetaManagedAgentsMemoryStore> retrieve(MemoryStoreRetrieveParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<BetaManagedAgentsMemoryStore> retrieve(MemoryStoreRetrieveParams params)
-
retrieve
CompletableFuture<BetaManagedAgentsMemoryStore> retrieve(String memoryStoreId, RequestOptions requestOptions)
-
update
CompletableFuture<BetaManagedAgentsMemoryStore> update(String memoryStoreId)
Update a memory store
-
update
CompletableFuture<BetaManagedAgentsMemoryStore> update(String memoryStoreId, MemoryStoreUpdateParams params, RequestOptions requestOptions)
-
update
CompletableFuture<BetaManagedAgentsMemoryStore> update(String memoryStoreId, MemoryStoreUpdateParams params)
-
update
abstract CompletableFuture<BetaManagedAgentsMemoryStore> update(MemoryStoreUpdateParams params, RequestOptions requestOptions)
-
update
CompletableFuture<BetaManagedAgentsMemoryStore> update(MemoryStoreUpdateParams params)
-
update
CompletableFuture<BetaManagedAgentsMemoryStore> update(String memoryStoreId, RequestOptions requestOptions)
-
list
CompletableFuture<MemoryStoreListPageAsync> list()
List memory stores
-
list
abstract CompletableFuture<MemoryStoreListPageAsync> list(MemoryStoreListParams params, RequestOptions requestOptions)
-
list
CompletableFuture<MemoryStoreListPageAsync> list(MemoryStoreListParams params)
-
list
CompletableFuture<MemoryStoreListPageAsync> list(RequestOptions requestOptions)
-
delete
CompletableFuture<BetaManagedAgentsDeletedMemoryStore> delete(String memoryStoreId)
Delete a memory store
-
delete
CompletableFuture<BetaManagedAgentsDeletedMemoryStore> delete(String memoryStoreId, MemoryStoreDeleteParams params, RequestOptions requestOptions)
-
delete
CompletableFuture<BetaManagedAgentsDeletedMemoryStore> delete(String memoryStoreId, MemoryStoreDeleteParams params)
-
delete
abstract CompletableFuture<BetaManagedAgentsDeletedMemoryStore> delete(MemoryStoreDeleteParams params, RequestOptions requestOptions)
-
delete
CompletableFuture<BetaManagedAgentsDeletedMemoryStore> delete(MemoryStoreDeleteParams params)
-
delete
CompletableFuture<BetaManagedAgentsDeletedMemoryStore> delete(String memoryStoreId, RequestOptions requestOptions)
-
archive
CompletableFuture<BetaManagedAgentsMemoryStore> archive(String memoryStoreId)
Archive a memory store
-
archive
CompletableFuture<BetaManagedAgentsMemoryStore> archive(String memoryStoreId, MemoryStoreArchiveParams params, RequestOptions requestOptions)
-
archive
CompletableFuture<BetaManagedAgentsMemoryStore> archive(String memoryStoreId, MemoryStoreArchiveParams params)
-
archive
abstract CompletableFuture<BetaManagedAgentsMemoryStore> archive(MemoryStoreArchiveParams params, RequestOptions requestOptions)
-
archive
CompletableFuture<BetaManagedAgentsMemoryStore> archive(MemoryStoreArchiveParams params)
-
archive
CompletableFuture<BetaManagedAgentsMemoryStore> archive(String memoryStoreId, RequestOptions requestOptions)
-
-
-
-