Class MemoryStoreServiceImpl
-
- All Implemented Interfaces:
-
com.anthropic.services.blocking.beta.MemoryStoreService
public final class MemoryStoreServiceImpl implements MemoryStoreService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classMemoryStoreServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description MemoryStoreService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. MemoryServicememories()MemoryVersionServicememoryVersions()MemoryStoreServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. BetaManagedAgentsMemoryStorecreate(MemoryStoreCreateParams params, RequestOptions requestOptions)BetaManagedAgentsMemoryStoreretrieve(MemoryStoreRetrieveParams params, RequestOptions requestOptions)BetaManagedAgentsMemoryStoreupdate(MemoryStoreUpdateParams params, RequestOptions requestOptions)MemoryStoreListPagelist(MemoryStoreListParams params, RequestOptions requestOptions)BetaManagedAgentsDeletedMemoryStoredelete(MemoryStoreDeleteParams params, RequestOptions requestOptions)BetaManagedAgentsMemoryStorearchive(MemoryStoreArchiveParams params, RequestOptions requestOptions)-
Methods inherited from class com.anthropic.services.blocking.beta.MemoryStoreService
archive, archive, archive, archive, archive, create, delete, delete, delete, delete, delete, list, list, list, retrieve, retrieve, retrieve, retrieve, retrieve, update, update, update, update, update -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withRawResponse
MemoryStoreService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
memories
MemoryService memories()
-
memoryVersions
MemoryVersionService memoryVersions()
-
withOptions
MemoryStoreService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
BetaManagedAgentsMemoryStore create(MemoryStoreCreateParams params, RequestOptions requestOptions)
-
retrieve
BetaManagedAgentsMemoryStore retrieve(MemoryStoreRetrieveParams params, RequestOptions requestOptions)
-
update
BetaManagedAgentsMemoryStore update(MemoryStoreUpdateParams params, RequestOptions requestOptions)
-
list
MemoryStoreListPage list(MemoryStoreListParams params, RequestOptions requestOptions)
-
delete
BetaManagedAgentsDeletedMemoryStore delete(MemoryStoreDeleteParams params, RequestOptions requestOptions)
-
archive
BetaManagedAgentsMemoryStore archive(MemoryStoreArchiveParams params, RequestOptions requestOptions)
-
-
-
-