JavaScript is disabled on your browser.
Skip navigation links
Overview
Package
Class
Tree
Deprecated
Index
Help
All Classes
SEARCH:
JavaScript is disabled on your browser.
Deprecated API
Contents
Methods
Methods
Method
Description
com.anthropic.core.getValueClass()
com.anthropic.core.getNullValue()
com.anthropic.core.getEmptyValue()
com.fasterxml.jackson.databind.getNullValue()
com.fasterxml.jackson.databind.jsonschema.getSchema(com.fasterxml.jackson.databind.SerializerProvider,java.lang.reflect.Type)
com.fasterxml.jackson.databind.jsonschema.getSchema(com.fasterxml.jackson.databind.SerializerProvider,java.lang.reflect.Type,java.lang.Boolean)
com.fasterxml.jackson.databind.isEmpty(T)
com.anthropic.core.getNullValue()
com.anthropic.core.getValueClass()
com.anthropic.core.getEmptyValue()
com.anthropic.core.getNullValue()
com.anthropic.core.getValueClass()
com.anthropic.core.getEmptyValue()
com.anthropic.models.beta.messages.outputFormat(com.anthropic.models.beta.messages.BetaJsonOutputFormat)
Deprecated: Use
output_config.format
instead.
com.anthropic.models.beta.messages.outputFormat(java.util.Optional)
Alias for calling
Builder.outputFormat
with
outputFormat.orElse(null)
.
com.anthropic.models.beta.messages.outputFormat(com.anthropic.core.JsonField)
Sets
Builder.outputFormat
to an arbitrary JSON value.
com.anthropic.models.beta.messages.outputFormat(com.anthropic.models.beta.messages.BetaJsonOutputFormat)
Deprecated: Use
output_config.format
instead.
com.anthropic.models.beta.messages.outputFormat(java.util.Optional)
Alias for calling
Builder.outputFormat
with
outputFormat.orElse(null)
.
com.anthropic.models.beta.messages.outputFormat(com.anthropic.core.JsonField)
Sets
Builder.outputFormat
to an arbitrary JSON value.
com.anthropic.models.beta.messages.outputFormat()
Deprecated: Use
output_config.format
instead.
com.anthropic.models.beta.messages._outputFormat()
Returns the raw JSON value of outputFormat.
com.anthropic.models.beta.messages.outputFormat()
Deprecated: Use
output_config.format
instead.
com.anthropic.models.beta.messages._outputFormat()
Returns the raw JSON value of
outputFormat
.
com.anthropic.models.beta.messages.outputFormat(com.anthropic.models.beta.messages.BetaJsonOutputFormat)
Deprecated: Use
output_config.format
instead.
com.anthropic.models.beta.messages.outputFormat(java.util.Optional)
Alias for calling
Builder.outputFormat
with
outputFormat.orElse(null)
.
com.anthropic.models.beta.messages.outputFormat(com.anthropic.core.JsonField)
Sets
Builder.outputFormat
to an arbitrary JSON value.
com.anthropic.models.beta.messages.outputFormat(java.lang.Class,com.anthropic.core.JsonSchemaLocalValidation)
Sets the output format to a JSON schema derived from the structure of the given class.
com.anthropic.models.beta.messages.temperature(java.lang.Double)
Amount of randomness injected into the response.
com.anthropic.models.beta.messages.temperature(com.anthropic.core.JsonField)
Sets
Builder.temperature
to an arbitrary JSON value.
com.anthropic.models.beta.messages.topK(java.lang.Long)
Only sample from the top K options for each subsequent token.
com.anthropic.models.beta.messages.topK(com.anthropic.core.JsonField)
Sets
Builder.topK
to an arbitrary JSON value.
com.anthropic.models.beta.messages.topP(java.lang.Double)
Use nucleus sampling.
com.anthropic.models.beta.messages.topP(com.anthropic.core.JsonField)
Sets
Builder.topP
to an arbitrary JSON value.
com.anthropic.models.beta.messages.outputFormat(com.anthropic.models.beta.messages.BetaJsonOutputFormat)
Deprecated: Use
output_config.format
instead.
com.anthropic.models.beta.messages.outputFormat(java.util.Optional)
Alias for calling
Builder.outputFormat
with
outputFormat.orElse(null)
.
com.anthropic.models.beta.messages.outputFormat(com.anthropic.core.JsonField)
Sets
Builder.outputFormat
to an arbitrary JSON value.
com.anthropic.models.beta.messages.temperature(java.lang.Double)
Amount of randomness injected into the response.
com.anthropic.models.beta.messages.temperature(com.anthropic.core.JsonField)
Sets
Builder.temperature
to an arbitrary JSON value.
com.anthropic.models.beta.messages.topK(java.lang.Long)
Only sample from the top K options for each subsequent token.
com.anthropic.models.beta.messages.topK(com.anthropic.core.JsonField)
Sets
Builder.topK
to an arbitrary JSON value.
com.anthropic.models.beta.messages.topP(java.lang.Double)
Use nucleus sampling.
com.anthropic.models.beta.messages.topP(com.anthropic.core.JsonField)
Sets
Builder.topP
to an arbitrary JSON value.
com.anthropic.models.beta.messages.outputFormat()
Deprecated: Use
output_config.format
instead.
com.anthropic.models.beta.messages.temperature()
Amount of randomness injected into the response.
com.anthropic.models.beta.messages.topK()
Only sample from the top K options for each subsequent token.
com.anthropic.models.beta.messages.topP()
Use nucleus sampling.
com.anthropic.models.beta.messages._outputFormat()
Returns the raw JSON value of outputFormat.
com.anthropic.models.beta.messages._temperature()
Returns the raw JSON value of temperature.
com.anthropic.models.beta.messages._topK()
Returns the raw JSON value of topK.
com.anthropic.models.beta.messages._topP()
Returns the raw JSON value of topP.
com.anthropic.models.beta.messages.outputFormat()
Deprecated: Use
output_config.format
instead.
com.anthropic.models.beta.messages.temperature()
Amount of randomness injected into the response.
com.anthropic.models.beta.messages.topK()
Only sample from the top K options for each subsequent token.
com.anthropic.models.beta.messages.topP()
Use nucleus sampling.
com.anthropic.models.beta.messages._outputFormat()
Returns the raw JSON value of
outputFormat
.
com.anthropic.models.beta.messages._temperature()
Returns the raw JSON value of
temperature
.
com.anthropic.models.beta.messages._topK()
Returns the raw JSON value of
topK
.
com.anthropic.models.beta.messages._topP()
Returns the raw JSON value of
topP
.
com.anthropic.models.beta.messages.outputFormat(java.lang.Class,com.anthropic.core.JsonSchemaLocalValidation)
Sets the output format to a JSON schema derived from the structure of the given class.
com.anthropic.models.beta.messages.batches.outputFormat(com.anthropic.models.beta.messages.BetaJsonOutputFormat)
Deprecated: Use
output_config.format
instead.
com.anthropic.models.beta.messages.batches.outputFormat(java.util.Optional)
Alias for calling
Builder.outputFormat
with
outputFormat.orElse(null)
.
com.anthropic.models.beta.messages.batches.outputFormat(com.anthropic.core.JsonField)
Sets
Builder.outputFormat
to an arbitrary JSON value.
com.anthropic.models.beta.messages.batches.temperature(java.lang.Double)
Amount of randomness injected into the response.
com.anthropic.models.beta.messages.batches.temperature(com.anthropic.core.JsonField)
Sets
Builder.temperature
to an arbitrary JSON value.
com.anthropic.models.beta.messages.batches.topK(java.lang.Long)
Only sample from the top K options for each subsequent token.
com.anthropic.models.beta.messages.batches.topK(com.anthropic.core.JsonField)
Sets
Builder.topK
to an arbitrary JSON value.
com.anthropic.models.beta.messages.batches.topP(java.lang.Double)
Use nucleus sampling.
com.anthropic.models.beta.messages.batches.topP(com.anthropic.core.JsonField)
Sets
Builder.topP
to an arbitrary JSON value.
com.anthropic.models.beta.messages.batches.outputFormat()
Deprecated: Use
output_config.format
instead.
com.anthropic.models.beta.messages.batches.temperature()
Amount of randomness injected into the response.
com.anthropic.models.beta.messages.batches.topK()
Only sample from the top K options for each subsequent token.
com.anthropic.models.beta.messages.batches.topP()
Use nucleus sampling.
com.anthropic.models.beta.messages.batches._outputFormat()
Returns the raw JSON value of outputFormat.
com.anthropic.models.beta.messages.batches._temperature()
Returns the raw JSON value of temperature.
com.anthropic.models.beta.messages.batches._topK()
Returns the raw JSON value of topK.
com.anthropic.models.beta.messages.batches._topP()
Returns the raw JSON value of topP.
com.anthropic.models.completions.temperature(java.lang.Double)
Amount of randomness injected into the response.
com.anthropic.models.completions.temperature(com.anthropic.core.JsonField)
Sets
Builder.temperature
to an arbitrary JSON value.
com.anthropic.models.completions.topK(java.lang.Long)
Only sample from the top K options for each subsequent token.
com.anthropic.models.completions.topK(com.anthropic.core.JsonField)
Sets
Builder.topK
to an arbitrary JSON value.
com.anthropic.models.completions.topP(java.lang.Double)
Use nucleus sampling.
com.anthropic.models.completions.topP(com.anthropic.core.JsonField)
Sets
Builder.topP
to an arbitrary JSON value.
com.anthropic.models.completions.temperature(java.lang.Double)
Amount of randomness injected into the response.
com.anthropic.models.completions.temperature(com.anthropic.core.JsonField)
Sets
Builder.temperature
to an arbitrary JSON value.
com.anthropic.models.completions.topK(java.lang.Long)
Only sample from the top K options for each subsequent token.
com.anthropic.models.completions.topK(com.anthropic.core.JsonField)
Sets
Builder.topK
to an arbitrary JSON value.
com.anthropic.models.completions.topP(java.lang.Double)
Use nucleus sampling.
com.anthropic.models.completions.topP(com.anthropic.core.JsonField)
Sets
Builder.topP
to an arbitrary JSON value.
com.anthropic.models.completions.temperature()
Amount of randomness injected into the response.
com.anthropic.models.completions.topK()
Only sample from the top K options for each subsequent token.
com.anthropic.models.completions.topP()
Use nucleus sampling.
com.anthropic.models.completions._temperature()
Returns the raw JSON value of temperature.
com.anthropic.models.completions._topK()
Returns the raw JSON value of topK.
com.anthropic.models.completions._topP()
Returns the raw JSON value of topP.
com.anthropic.models.completions.temperature()
Amount of randomness injected into the response.
com.anthropic.models.completions.topK()
Only sample from the top K options for each subsequent token.
com.anthropic.models.completions.topP()
Use nucleus sampling.
com.anthropic.models.completions._temperature()
Returns the raw JSON value of
temperature
.
com.anthropic.models.completions._topK()
Returns the raw JSON value of
topK
.
com.anthropic.models.completions._topP()
Returns the raw JSON value of
topP
.
com.anthropic.models.messages.temperature(java.lang.Double)
Amount of randomness injected into the response.
com.anthropic.models.messages.temperature(com.anthropic.core.JsonField)
Sets
Builder.temperature
to an arbitrary JSON value.
com.anthropic.models.messages.topK(java.lang.Long)
Only sample from the top K options for each subsequent token.
com.anthropic.models.messages.topK(com.anthropic.core.JsonField)
Sets
Builder.topK
to an arbitrary JSON value.
com.anthropic.models.messages.topP(java.lang.Double)
Use nucleus sampling.
com.anthropic.models.messages.topP(com.anthropic.core.JsonField)
Sets
Builder.topP
to an arbitrary JSON value.
com.anthropic.models.messages.temperature(java.lang.Double)
Amount of randomness injected into the response.
com.anthropic.models.messages.temperature(com.anthropic.core.JsonField)
Sets
Builder.temperature
to an arbitrary JSON value.
com.anthropic.models.messages.topK(java.lang.Long)
Only sample from the top K options for each subsequent token.
com.anthropic.models.messages.topK(com.anthropic.core.JsonField)
Sets
Builder.topK
to an arbitrary JSON value.
com.anthropic.models.messages.topP(java.lang.Double)
Use nucleus sampling.
com.anthropic.models.messages.topP(com.anthropic.core.JsonField)
Sets
Builder.topP
to an arbitrary JSON value.
com.anthropic.models.messages.temperature()
Amount of randomness injected into the response.
com.anthropic.models.messages.topK()
Only sample from the top K options for each subsequent token.
com.anthropic.models.messages.topP()
Use nucleus sampling.
com.anthropic.models.messages._temperature()
Returns the raw JSON value of temperature.
com.anthropic.models.messages._topK()
Returns the raw JSON value of topK.
com.anthropic.models.messages._topP()
Returns the raw JSON value of topP.
com.anthropic.models.messages.temperature()
Amount of randomness injected into the response.
com.anthropic.models.messages.topK()
Only sample from the top K options for each subsequent token.
com.anthropic.models.messages.topP()
Use nucleus sampling.
com.anthropic.models.messages._temperature()
Returns the raw JSON value of
temperature
.
com.anthropic.models.messages._topK()
Returns the raw JSON value of
topK
.
com.anthropic.models.messages._topP()
Returns the raw JSON value of
topP
.
com.anthropic.models.messages.batches.temperature(java.lang.Double)
Amount of randomness injected into the response.
com.anthropic.models.messages.batches.temperature(com.anthropic.core.JsonField)
Sets
Builder.temperature
to an arbitrary JSON value.
com.anthropic.models.messages.batches.topK(java.lang.Long)
Only sample from the top K options for each subsequent token.
com.anthropic.models.messages.batches.topK(com.anthropic.core.JsonField)
Sets
Builder.topK
to an arbitrary JSON value.
com.anthropic.models.messages.batches.topP(java.lang.Double)
Use nucleus sampling.
com.anthropic.models.messages.batches.topP(com.anthropic.core.JsonField)
Sets
Builder.topP
to an arbitrary JSON value.
com.anthropic.models.messages.batches.temperature()
Amount of randomness injected into the response.
com.anthropic.models.messages.batches.topK()
Only sample from the top K options for each subsequent token.
com.anthropic.models.messages.batches.topP()
Use nucleus sampling.
com.anthropic.models.messages.batches._temperature()
Returns the raw JSON value of temperature.
com.anthropic.models.messages.batches._topK()
Returns the raw JSON value of topK.
com.anthropic.models.messages.batches._topP()
Returns the raw JSON value of topP.